about summary refs log tree commit diff stats
path: root/text_tests.lua
diff options
context:
space:
mode:
authorKartik K. Agaram <vc@akkartik.com>2023-03-19 11:46:44 -0700
committerKartik K. Agaram <vc@akkartik.com>2023-03-19 11:48:47 -0700
commit0c06c60622c09bed2ff19ea2a836820173387f29 (patch)
tree63700c45feb1b86e87bf2cb6e59eb988bde5757c /text_tests.lua
parent30e75991ce3430550d7565c8141fc8ed68c67290 (diff)
downloadlines.love-0c06c60622c09bed2ff19ea2a836820173387f29.tar.gz
give a test a unique name
Diffstat (limited to 'text_tests.lua')
-rw-r--r--text_tests.lua6
1 files changed, 3 insertions, 3 deletions
diff --git a/text_tests.lua b/text_tests.lua
index 7cf980b..4fe0ca8 100644
--- a/text_tests.lua
+++ b/text_tests.lua
@@ -369,7 +369,7 @@ function test_draw_word_wrapping_text()
 end
 
 function test_click_on_wrapping_line()
   -- display two lines with cursor on one of them
   App.screen.init{width=50, height=80}
   Editor_state = edit.initialize_test_state()
   Editor_state.lines = load_array{'abc def ghi jkl mno pqr stu'}
@@ -387,7 +387,7 @@ function test_click_on_wrapping_line()
 end
 
 function test_click_on_wrapping_line_takes_margins_into_account()
   -- display two lines with cursor on one of them
   App.screen.init{width=100, height=80}
   Editor_state = edit.initialize_test_state()
   Editor_state.left = 50  -- occupy only right side of screen
@@ -441,7 +441,7 @@ function test_draw_wrapping_text_containing_non_ascii()
   App.screen.check(y, '’m a', 'screen:3')
 end
 
-function test_click_on_wrapping_line()
+function test_click_past_end_of_screen_line()
   -- display a wrapping line
   App.screen.init{width=75, height=80}
   Editor_state = edit.initialize_test_state()
@@ -369,7 +369,7 @@ function test_draw_word_wrapping_text()
 
 function test_click_on_wrapping_line()
-  -- display two lines with cursor on one of them
+  -- display two screen lines with cursor on one of them
   App.screen.init{width=50, height=80}
   Editor_state = edit.initialize_test_state()
@@ -387,7 +387,7 @@ function test_click_on_wrapping_line()
 
 function test_click_on_wrapping_line_takes_margins_into_account()
-  -- display two lines with cursor on one of them
+  -- display two screen lines with cursor on one of them
   App.screen.init{width=100, height=80}
   Editor_state = edit.initialize_test_state()